import React, { Component } from "react";
import { NavigationContainer } from "@react-navigation/native";
import { createStackNavigator } from "@react-navigation/stack";
import PI from "./PI";
import ThankYou from "./src/Screens/ThankYou";
import Header from "./src/Screens/Header";
import VideoRecorder from "./src/common/VideoRecorder";
import VideoPreview from "./src/common/VideoPreview";
import DocumentUpload from "./src/common/DocumentUpload";
import { Provider as PaperProvider, DefaultTheme } from "react-native-paper";
import { navigationRef } from "./src/common/RootNavigation";
import { Provider } from "react-redux";
import store from "./src/redux/store";
import Progress from "./src/Screens/Progress";
// import Tutorial from "./src/Screens/Tutorial";
import Camera from "./src/Screens/Camera";
import PreviewImage from "./src/Screens/PreviewImage";
import Orientation from "../../node_modules/react-native-orientation";
import Toturial from "./src/Screens/Toturial";
import InCorrectImages from "./src/Screens/InCorrectImages";
import Geolocation from "react-native-geolocation-service";
import Database from "../../Components/common/Database";

// Localization
const { setI18nConfig, translate } = require("./src/common/localize/i18n");
let realm = Database.getRealm();

import * as RNLocalize from "react-native-localize";
import WithQuote from "./src/Screens/WithQuote";
import WithOutQuote from "./src/Screens/WithOutQuote";
import { PermissionsAndroid } from "react-native";

class App extends Component {
  constructor(props) {
    super(props);
    setI18nConfig();
  }
  componentDidMount() {
    this.getPermission();
    this.requestLocationPermission();
    console.disableYellowBox = true;
    Orientation.lockToPortrait();
    RNLocalize.addEventListener("change", this.handleLocalizationChange);
  }
  componentWillUnmount() {
    RNLocalize.removeEventListener("change", this.handleLocalizationChange);
  }

  async getPermission() {
    const grantedCamera = await PermissionsAndroid.request(
      PermissionsAndroid.PERMISSIONS.CAMERA
    );
    const grantedAudio = await PermissionsAndroid.request(
      PermissionsAndroid.PERMISSIONS.RECORD_AUDIO
    );
    const grantedLocation = await PermissionsAndroid.request(
      PermissionsAndroid.PERMISSIONS.ACCESS_FINE_LOCATION
    );
    const grantedWrite = await PermissionsAndroid.request(
      PermissionsAndroid.PERMISSIONS.WRITE_EXTERNAL_STORAGE
    );
    const grantedRead = await PermissionsAndroid.request(
      PermissionsAndroid.PERMISSIONS.READ_EXTERNAL_STORAGE
    );

    if (
      grantedCamera !== PermissionsAndroid.RESULTS.GRANTED ||
      grantedAudio !== PermissionsAndroid.RESULTS.GRANTED ||
      grantedLocation !== PermissionsAndroid.RESULTS.GRANTED ||
      grantedCamera !== PermissionsAndroid.RESULTS.GRANTED ||
      grantedAudio !== PermissionsAndroid.RESULTS.GRANTED
    )
      Alert.alert(translate("Permission denied"));
  }

  async requestLocationPermission() {
    if (Platform.OS === "ios") {
      this.getOneTimeLocation();
    } else {
      try {
        const granted = await PermissionsAndroid.request(
          PermissionsAndroid.PERMISSIONS.ACCESS_FINE_LOCATION
        );

        if (granted === PermissionsAndroid.RESULTS.GRANTED) {
          //To Check, If Permission is granted
          this.getOneTimeLocation();
        } else {
          console.log("Permission Denied");
        }
      } catch (err) {
        console.warn(err);
      }
    }
  }

  // current location
  getOneTimeLocation() {
    Geolocation.getCurrentPosition(
      (position) => {
        console.log("AAAAAAAAAAAAAAAAA", position);

        // Saving data in realm
        realm.write(() => {
          realm.delete(realm.objects("PILocation"));
          realm.create("PILocation", {
            lat: position?.coords?.latitude.toString(),
            long: position?.coords?.longitude.toString(),
          });
        });
        var PILocation = realm.objects("PILocation");
        console.log("_____________________________________", PILocation);
      },
      (error) => {
        // See error code charts below.
        console.log(error.code, error.message);
      },
      { enableHighAccuracy: true, timeout: 15000, maximumAge: 10000 }
    );
  }

  handleLocalizationChange = () => {
    this.forceUpdate();
    setI18nConfig();
  };
  render() {
    const Stack = createStackNavigator();
    return (
      <NavigationContainer
        ref={navigationRef}
        theme={DefaultTheme}
        independent={true}
      >
        <PaperProvider theme={DefaultTheme}>
          <Provider store={store}>
            {this.props.props.route.params.isFromHomeScreen ? (
              <Stack.Navigator screenOptions={{ headerShown: false }}>
                <Stack.Screen
                  name="WithQuote"
                  component={WithQuote}
                  initialParams={this.props}
                />
                <Stack.Screen
                  name="WithOutQuote"
                  component={WithOutQuote}
                  initialParams={this.props}
                />
                <Stack.Screen
                  name="Toturial"
                  component={Toturial}
                  initialParams={this.props}
                />
                <Stack.Screen
                  name="PI"
                  component={PI}
                  initialParams={this.props}
                />
                <Stack.Screen
                  name="Progress"
                  component={Progress}
                  initialParams={this.props}
                />
                <Stack.Screen
                  name="ThankYou"
                  component={ThankYou}
                  initialParams={this.props}
                />
                <Stack.Screen
                  name="InCorrectImages"
                  component={InCorrectImages}
                />
                <Stack.Screen name="Camera" component={Camera} />
                <Stack.Screen
                  name="PreviewImage"
                  component={PreviewImage}
                  initialParams={this.props}
                />
              </Stack.Navigator>
            ) : (
              <Stack.Navigator screenOptions={{ headerShown: false }}>
                <Stack.Screen
                  name="Toturial"
                  component={Toturial}
                  initialParams={this.props}
                />
                <Stack.Screen
                  name="PI"
                  component={PI}
                  initialParams={this.props}
                />
                <Stack.Screen name="Progress" component={Progress} />
                <Stack.Screen
                  name="ThankYou"
                  component={ThankYou}
                  initialParams={this.props}
                />
                <Stack.Screen
                  name="InCorrectImages"
                  component={InCorrectImages}
                />
                <Stack.Screen name="Camera" component={Camera} />
                <Stack.Screen
                  name="PreviewImage"
                  component={PreviewImage}
                  initialParams={this.props}
                />

                {/* <Stack.Screen name="Tutorial" component={Tutorial} />
               /> */}
              </Stack.Navigator>
            )}
          </Provider>
        </PaperProvider>
      </NavigationContainer>
    );
  }
}

export default App;
