import React, { useEffect } from "react";
import { StyleSheet, View, Image, Text, BackHandler } from "react-native";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import { ProgressBar } from "react-native-paper";
import reactotron from "reactotron-react-native";
import Header from "./Header";
import Orientation from "../../../react-native-orientation";
import { useSelector } from "react-redux";

const Progress = ({ navigation, route }) => {
  const [, updateState] = React.useState();
  const forceUpdate = React.useCallback(() => updateState({}), []);
  const UploadImageDataCount = useSelector(
    (state) =>
      state.UploadImageData?.uploadImageInfo?.uploadImageInfo?.uploadImageCount
  );
  const imageClickedCountDetails = useSelector(
    (state) => state.imageClickedCountDetails
  );

  const { activityId } = route.params;
  let TotalImage = 0;
  TotalImage =
    imageClickedCountDetails?.ImageClickedInfo?.totalImageClicked
      ?.ImageClickedCount;

  useEffect(() => {
    console.log(
      "imageClickedCountDetails?.totalImageClicked?.ImageClickedCount",
      imageClickedCountDetails?.ImageClickedInfo?.totalImageClicked
        ?.ImageClickedCount
    );
    Orientation.lockToPortrait();
    const backHandler = BackHandler.addEventListener(
      "hardwareBackPress",
      () => {
        return true;
      }
    );

    return () => {
      backHandler.remove();
    };
  }, []);

  // navigation
  const navigateTOthankYou = () => {
    if (UploadImageDataCount + 1 >= TotalImage) {
      navigation.navigate("ThankYou", { activityId: activityId });
    }
  };

  return (
    <View style={styles.main}>
      <Header
        onlanguagechange={() => {
          forceUpdate();
        }}
        onbackPress={() => {
          navigation.goBack();
        }}
      />
      {/* GIF view */}
      <View style={styles.gifView}>
        <Image
          source={{
            uri: "https://d2h44aw7l5xdvz.cloudfront.net/assets/gif/time-animation-loader.gif",
          }}
          style={{ width: 146, height: 146, alignSelf: "center" }}
        />
      </View>
      {/* Progress View */}
      <View style={styles.progressView}>
        <Text style={styles.processingText}>
          {translate("Processing Images") + " "}
          {!!UploadImageDataCount && !!TotalImage
            ? UploadImageDataCount + " / " + TotalImage
            : 0 + " / " + 0}
        </Text>
        <ProgressBar
          progress={UploadImageDataCount / TotalImage}
          color={"#FFBB00"}
          style={{ height: 12, borderRadius: 6, backgroundColor: "#F5F5F5" }}
        />
        {navigateTOthankYou()}
      </View>
    </View>
  );
};
const styles = StyleSheet.create({
  main: {
    flex: 1,
    backgroundColor: "#FFFFFF",
  },
  gifView: {
    flex: 0.5,
    justifyContent: "flex-end",
    marginBottom: 40,
    marginLeft: 24,
    marginRight: 24,
  },
  progressView: {
    flex: 0.5,
    marginLeft: 24,
    marginRight: 24,
  },
  processingText: {
    fontFamily: "Muli-Bold",
    fontSize: 20,
    alignSelf: "center",
    marginBottom: 15,
  },
});
export default Progress;
