import { Image, ScrollView, StyleSheet, Text, View } from "react-native";
import React, { useEffect, useRef, useState } from "react";
import Header from "../Screens/Header";
import SqureRadio from "../common/SqureRadio";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import {
  TextInput,
  PrimaryButton,
  RoundButton,
  Spinner,
} from "../common/ThemedComponents";
import { SCREEN_WIDTH } from "react-native-digitcamera/lib/commonjs/common/Constants";
import ProductCard from "react-native-digitcamera/src/common/ProductCard";
import Colors from "react-native-digitcamera/lib/commonjs/common/Colors";
import { renderErrorMsge } from "react-native-digitcamera/src/common/Validation";
import { getActivityid } from "react-native-digitcamera/src/common/Services/getActivityid";
import reactotron from "reactotron-react-native";
import { useDispatch } from "react-redux";
import Database from "../../../../Components/common/Database";
import Modal from "../common/Modal";

let realm = Database.getRealm();
const girl_selfi = require("../common/Image/girl_selfi.png");
const car = require("../common/Image/car.png");
const Bike = require("../common/Image/Bike.png");
const cummercial = require("../common/Image/cummercial.png");

const NCB_SLABS = [
  { ncb: 0, name: "0%", id: 1, value: "ZERO" },
  { ncb: 20, name: "20%", id: 2, value: "TWENTY" },
  { ncb: 25, name: "25%", id: 3, value: "TWENTY_FIVE" },
  { ncb: 35, name: "35%", id: 4, value: "THIRTY_FIVE" },
  { ncb: 45, name: "45%", id: 5, value: "FORTY_FIVE" },
  { ncb: 50, name: "50%", id: 6, value: "FIFTY" },
].reverse();

const WithOutClicked = ({ navigation, route }) => {
  const [, updateState] = React.useState();
  const forceUpdate = React.useCallback(() => updateState({}), []);
  const [_4Wclicked, set4wclicked] = useState(false);
  const [_2Wclicked, set2wclicked] = useState(false);
  const [cvclicked, setCVclicked] = useState(false);
  const [ncbDisabled, setncbDisabled] = useState(false);
  const [selectedNCB, setselectedNCB] = useState("");
  const [isVechicleTypeSelected, setIsVechicleTypeSelected] = useState(false);
  const [registrationNumber, setRegistrationNumber] = useState("");
  const [activityTypeId, setActivityTypeId] = useState(null);
  const [isLoading, setISsLoading] = useState(false);
  const [isPIModalVisible, setisPIModalVisible] = useState(false);

  const dispatch = useDispatch();
  const {
    agentEmail,
    agentName,
    agentMobile,
    isFromHomeScreen,
    isFromManualPI,
  } = route.params;

  var activityData;

  //to get activity id and activityTypeid
  const callGetActivityid = async () => {
    try {
      const body = {
        activityTypeId: activityTypeId,
        customerDetailData: {
          emailId: agentEmail,
          name: agentName,
          phoneNo: agentMobile,
        },
        licensePlateNumber: registrationNumber,
        previousPolicyExpired: true,
        quoteNumber: "",
        usrNcb: selectedNCB?.ncb,
      };
      activityData = await getActivityid({ body });

      // added data in redux
      dispatch({
        type: "ACTIVITY_DATA",
        payload: {
          activityId: activityData?.activityID,
          activityTypeId: activityData?.activityTypeId,
          licensePlateNumber: registrationNumber,
          isFromHomeScreen: true,
          quoteNumber: "",
        },
      });
      realm.write(() => {
        realm.delete(realm.objects("PIVechicleData"));
        realm.create("PIVechicleData", {
          activityId: activityData?.activityID,
          activityTypeId: activityData?.activityTypeId,
          licensePlateNumber: registrationNumber,
          isFromHomeScreen: isFromHomeScreen,
          isFromManualPI: isFromManualPI,
          quoteNumber: "",
        });
      });

      var RealmData = realm.objects("PIVechicleData");
      console.log("WWWWWWWWWWWW Realm data withOutQuote ", RealmData);
      setISsLoading(false);
      navigation.navigate("Toturial");
    } catch (error) {
      console.log("@@@@@@@@@@@@", error);

      setISsLoading(true);
    }
  };
  const PreinspectionAlertUx = () => {
    return (
      <View style={{ marginLeft: 16, marginRight: 16 }}>
        <Text
          style={{
            fontSize: 14,
            fontFamily: "Muli-Regular",
            marginBottom: 16,
            lineHeight: 22,
          }}
        >
          {translate(
            "It seems like you are already in middle of a pre-inspection process You can either continue from where you left off or start from begining"
          )}
        </Text>
        <PrimaryButton
          onPress={() => {
            setisPIModalVisible(false);
            navigation.navigate("Toturial");
          }}
        >
          {"Continue"}
        </PrimaryButton>
        <PrimaryButton
          onPress={() => {
            setisPIModalVisible(false), setISsLoading(true);
            clearAllRealmData(), callGetActivityid();
            clearReduxData();
          }}
          style={{ backgroundColor: "#FFFFFF", borderWidth: 1, marginTop: 16 }}
        >
          {"Start Over"}
        </PrimaryButton>
      </View>
    );
  };

  const preInspectionAlert = () => {
    return (
      <View>
        <Modal
          isVisible={isPIModalVisible}
          onBackdropPress={() => setisPIModalVisible(false)}
          onClose={() => isPIModalVisible}
          heading={"Preinspection Alert!"}
          isTranslate={true}
          headerImageVisible={false}
        >
          {PreinspectionAlertUx()}
        </Modal>
      </View>
    );
  };

  const clearAllRealmData = () => {
    realm.write(() => {
      realm.delete(realm.objects("PIOfflineData"));
    });
    realm.write(() => {
      realm.delete(realm.objects("PIVechicleData"));
    });
    realm.write(() => {
      realm.delete(realm.objects("PIVechicleInstruction"));
    });
    realm.write(() => {
      realm.delete(realm.objects("PIRetryCount"));
      realm.create("PIRetryCount", {
        retryCount: 0,
        index: 0,
        isAddNewImageData: false,
      });
    });
  };

  const clearReduxData = () => {
    dispatch({
      type: "CLEAR_REDUX",
    });
  };
  const checkPICondition = () => {
    var vechicleData = realm.objects("PIVechicleData");
    console.log(
      "*****************",
      vechicleData[0]?.licensePlateNumber,
      registrationNumber
    );
    if (vechicleData[0]?.licensePlateNumber == registrationNumber) {
      setisPIModalVisible(true);
    } else {
      setISsLoading(true);
      setisPIModalVisible(false);
      clearAllRealmData();
      callGetActivityid();
      clearReduxData();
    }
  };
  return (
    <View style={styles.main}>
      <ScrollView>
        <Spinner loading={isLoading} />
        <View style={styles.subView}>
          <Header
            hideArrowBackButton={false}
            onlanguagechange={() => {
              forceUpdate;
            }}
            onbackPress={() => {
              navigation.goBack();
            }}
          />
          {/* Image view */}
          <View style={styles.imageView}>
            <Text style={styles.subHeaderText}>
              {translate("Choose vehicle type")}
            </Text>

            <View style={{ flexDirection: "row" }}>
              {/* 4 W */}
              <ProductCard
                imageSource={car}
                title={translate("4 wheeler")}
                key={"4 wheeler"}
                onPress={() => {
                  set4wclicked(true);
                  set2wclicked(false);
                  setCVclicked(false);
                  setIsVechicleTypeSelected(true);
                  setActivityTypeId(5);
                }}
                style={{
                  marginLeft: 8,
                  marginBottom: 16,
                  width: (SCREEN_WIDTH - 100) / 3,
                  borderColor: _4Wclicked
                    ? Colors.digitYellow
                    : Colors.greyBlack,
                  borderWidth: 1,
                  borderRadius: 4,
                  backgroundColor: "white",
                  marginRight: 8,
                }}
              />

              {/* 2 W */}
              <ProductCard
                imageSource={Bike}
                title={translate("2 wheeler")}
                key={"2 wheeler"}
                onPress={() => {
                  set4wclicked(false);
                  set2wclicked(true);
                  setCVclicked(false);
                  setIsVechicleTypeSelected(true);
                  setActivityTypeId(26);
                }}
                style={{
                  marginLeft: 8,
                  marginBottom: 16,
                  width: (SCREEN_WIDTH - 100) / 3,
                  borderColor: _2Wclicked
                    ? Colors.digitYellow
                    : Colors.greyBlack,
                  borderWidth: 1,
                  borderRadius: 4,
                  backgroundColor: "white",
                  marginRight: 8,
                }}
              />

              {/* cummercial */}
              <ProductCard
                imageSource={cummercial}
                title={translate("Commercial")}
                key={"Commercial"}
                onPress={() => {
                  set4wclicked(false);
                  set2wclicked(false);
                  setCVclicked(true);
                  setIsVechicleTypeSelected(true);
                  setActivityTypeId(30);
                }}
                style={{
                  marginLeft: 8,
                  marginBottom: 16,
                  width: (SCREEN_WIDTH - 100) / 3,
                  borderColor: cvclicked
                    ? Colors.digitYellow
                    : Colors.greyBlack,
                  borderWidth: 1,
                  borderRadius: 4,
                  backgroundColor: "white",
                  marginRight: 8,
                }}
              />
            </View>
            {!isVechicleTypeSelected ? (
              <Text style={{ color: "red", marginLeft: 8 }}>
                {translate("Select Vechicle Type")}
              </Text>
            ) : null}
            <TextInput
              autoCapitalize="characters"
              style={{ marginLeft: 8, marginRight: 8, marginTop: 23 }}
              onChangeText={(value) => {
                setRegistrationNumber(value);
              }}
              label={translate("Enter Vehicle Reg No")}
              maxLength={10}
              errorMsge={
                Number(registrationNumber.length) < 10
                  ? renderErrorMsge({
                      type: "input",
                      text: "Registration Number",
                    })
                  : null
              }
            />
          </View>
          <View
            style={{
              width: SCREEN_WIDTH - 48,
              height: 1,
              borderRightWidth: 1,
              borderColor: "#F5F5F5",
              backgroundColor: "#F5F5F5",
            }}
          />
          {/* Text View */}
          <View style={styles.textView}>
            <Text style={styles.ncbHeading}>
              {translate("Select NCB percentage")}
            </Text>
            <SqureRadio
              data={NCB_SLABS}
              numberOfRecord={3}
              disabled={ncbDisabled}
              isFullValue={true}
              selected={(value) => {
                setselectedNCB(value);
              }}
              selectedvalue={selectedNCB.id}
              style={{ marginVertical: 20 }}
              noTranslation={true}
            />
            {selectedNCB.id ? null : (
              <Text style={{ color: "red" }}>
                {translate("Please select NCB")}
              </Text>
            )}
          </View>
          {preInspectionAlert()}
          {/* Button view */}
          <View style={styles.buttonView}>
            <PrimaryButton
              style={{ marginTop: 24 }}
              disabled={
                isVechicleTypeSelected &&
                registrationNumber.length >= 10 &&
                selectedNCB.id
                  ? false
                  : true
              }
              onPress={() => {
                checkPICondition();
              }}
            >
              {translate("Continue")}
            </PrimaryButton>
            <RoundButton
              style={{
                height: 50,
                borderColor: "#DDDDDD",
                borderWidth: 1,
                borderRadius: 16,
                marginTop: 18,
                width: SCREEN_WIDTH - 108,
                alignSelf: "center",
                justifyContent: "center",
                marginBottom: 20,
              }}
              Title={translate("I have Quote/Policy No")}
              onClicked={() => {
                navigation.navigate("WithQuote");
              }}
            ></RoundButton>
          </View>
        </View>
      </ScrollView>
    </View>
  );
};
export default WithOutClicked;

const styles = StyleSheet.create({
  main: {
    flex: 1,
    backgroundColor: "#FFFFFF",
  },
  imageView: {
    flex: 0.3,
    marginTop: 36,
  },
  textView: {
    flex: 0.55,
    marginLeft: 8,
  },
  buttonView: {
    flex: 0.15,
    marginLeft: 8,
  },
  welcomeText: {
    fontSize: 18,
    fontFamily: "Muli-ExtraBold",
    marginBottom: 9,
    marginTop: 52,
  },
  subText: {
    fontFamily: "Muli-Regular",
    fontSize: 14,
    marginBottom: 23,
  },
  subView: {
    flex: 1,
    marginLeft: 24,
    marginRight: 24,
  },
  subHeaderText: {
    fontSize: 16,
    fontFamily: "Muli-Bold",
    marginLeft: 8,
    marginBottom: 12,
  },
  ncbHeading: {
    fontFamily: "Muli-Bold",
    fontSize: 16,
    marginTop: 18,
    marginBottom: 12,
  },
});
