import { Image, StyleSheet, Text, View } from "react-native";
import React, { useEffect, useRef, useState } from "react";
import Header from "../Screens/Header";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import {
  TextInput,
  PrimaryButton,
  RoundButton,
  Spinner,
} from "../common/ThemedComponents";
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/lib/commonjs/common/Constants";
import { renderErrorMsge } from "react-native-digitcamera/src/common/Validation";
import { ScrollView } from "react-native-gesture-handler";
import { async } from "validate.js";
import { getActivityid } from "react-native-digitcamera/src/common/Services/getActivityid";
import { useDispatch } from "react-redux";
import Modal from "../common/Modal";
import Database from "../../../../Components/common/Database";
let realm = Database.getRealm();

const girl_selfi = require("../common/Image/girl_selfi.png");
const WithQuote = ({ navigation, route }) => {
  const [, updateState] = React.useState();
  const forceUpdate = React.useCallback(() => updateState({}), []);
  const [quoteNumber, setQuoteNumber] = useState("");
  const [isLoading, setISsLoading] = useState(false);
  const [isPIModalVisible, setisPIModalVisible] = useState(false);
  const dispatch = useDispatch();
  const {
    agentEmail,
    agentName,
    agentMobile,
    isFromHomeScreen,
    isFromManualPI,
  } = route.params;

  var activityData;

  useEffect(() => {}, []);
  //to get activity id and activityTypeid
  const callGetActivityid = async () => {
    try {
      //API call
      const body = {
        activityTypeId: 0,
        customerDetailData: {
          emailId: agentEmail,
          name: agentName,
          phoneNo: agentMobile,
        },
        licensePlateNumber: "",
        previousPolicyExpired: true,
        quoteNumber: quoteNumber,
        usrNcb: "0",
      };
      activityData = await getActivityid({ body });

      var registrationNumber = activityData?.additionalActivitiesList.filter(
        (item) => {
          if (item.key == "Registration Number") {
            return item;
          }
        }
      );
      setISsLoading(false);

      // adding data to redux
      dispatch({
        type: "ACTIVITY_DATA",
        payload: {
          activityId: activityData?.activityID,
          activityTypeId: activityData?.activityTypeId,
          licensePlateNumber: registrationNumber,
          isFromHomeScreen: isFromHomeScreen,
          isFromManualPI: isFromManualPI,
          quoteNumber: quoteNumber,
        },
      });
      realm.write(() => {
        realm.delete(realm.objects("PIVechicleData"));
        realm.create("PIVechicleData", {
          activityId: activityData?.activityID,
          activityTypeId: activityData?.activityTypeId,
          licensePlateNumber: registrationNumber[0].value,
          isFromHomeScreen: isFromHomeScreen,
          isFromManualPI: isFromManualPI,
          quoteNumber: quoteNumber,
        });
      });
      // var RealmData = realm.objects("PIVechicleData");
      // console.log("&&&&&&&&& ",RealmData);
      navigation.navigate("Toturial", {
        activityId: activityData?.activityID,
        activityTypeId: activityData?.activityTypeId,
        licensePlateNumber: registrationNumber[0]?.value,
      });
    } catch (error) {
      console.log("IN WithQuote => error in service ");
      setISsLoading(true);
    }
  };

  const PreinspectionAlertUx = () => {
    return (
      <View style={{ marginLeft: 16, marginRight: 16 }}>
        <Text
          style={{
            fontSize: 14,
            fontFamily: "Muli-Regular",
            marginBottom: 16,
            lineHeight: 22,
          }}
        >
          {translate(
            "It seems like you are already in middle of a pre-inspection process You can either continue from where you left off or start from begining"
          )}
        </Text>
        <PrimaryButton
          onPress={() => {
            setisPIModalVisible(false);
            navigation.navigate("Toturial", {
              activityId: activityData?.activityID,
              activityTypeId: activityData?.activityTypeId,
              licensePlateNumber: registrationNumber[0]?.value,
            });
          }}
        >
          {"Continue"}
        </PrimaryButton>
        <PrimaryButton
          onPress={() => {
            setisPIModalVisible(false),
              setISsLoading(true),
              clearAllRealmData(),
              callGetActivityid();
          }}
          style={{ backgroundColor: "#FFFFFF", borderWidth: 1, marginTop: 16 }}
        >
          {"Start Over"}
        </PrimaryButton>
      </View>
    );
  };

  const preInspectionAlert = () => {
    return (
      <View>
        <Modal
          isVisible={isPIModalVisible}
          onBackdropPress={() => setisPIModalVisible(false)}
          onClose={() => isPIModalVisible}
          heading={"Preinspection Alert!"}
          isTranslate={true}
          headerImageVisible={false}
        >
          {PreinspectionAlertUx()}
        </Modal>
      </View>
    );
  };

  const clearAllRealmData = () => {
    realm.write(() => {
      realm.delete(realm.objects("PIOfflineData"));
    });
    realm.write(() => {
      realm.delete(realm.objects("PIVechicleData"));
    });
    realm.write(() => {
      realm.delete(realm.objects("PIVechicleInstruction"));
    });
    realm.write(() => {
      realm.delete(realm.objects("PIRetryCount"));
      realm.create("PIRetryCount", {
        retryCount: 0,
        index: 0,
        isAddNewImageData: false,
      });
    });
  };

  const checkPICondition = () => {
    var vechicleData = realm.objects("PIVechicleData");
    if (vechicleData[0]?.quoteNumber == quoteNumber) {
      setisPIModalVisible(true);
    } else {
      setisPIModalVisible(true);
      setISsLoading(true);
      clearAllRealmData();
      callGetActivityid();
    }
  };
  return (
    <View style={styles.main}>
      <ScrollView>
        <Spinner loading={isLoading} />
        <View style={styles.subView}>
          <Header
            hideArrowBackButton={false}
            onlanguagechange={() => {
              forceUpdate;
            }}
            onbackPress={() => {
              if (isFromHomeScreen) {
                if (isFromManualPI) {
                  route.params.props.navigation.navigate("MIHomeScreen");
                } else {
                  route.params.props.navigation.navigate("BottomNavigation");
                }
              } else {
                route.params.props.navigation.navigate(
                  "PostplanPreviousPolicy"
                );
              }
            }}
          />
          {/* Image view */}
          <View style={styles.imageView}>
            <Image
              source={girl_selfi}
              style={{
                resizeMode: "center",
                width: SCREEN_WIDTH - 58,
                height: SCREEN_HEIGHT / 2.5,
              }}
            />
          </View>
          {/* Text View */}
          <View style={styles.textView}>
            <Text style={styles.welcomeText}>{translate("Welcome!")}</Text>
            <Text style={styles.subText}>
              {translate(
                "Our pre-inspection process is super simple and quick All you need to do is upload images of the vehicle by following instructions"
              )}
            </Text>

            <TextInput
              autoCapitalize="characters"
              label={translate("Enter Quote/Policy number")}
              // value={odometerReadings}
              onChangeText={(value) => {
                setQuoteNumber(value);
              }}
              errorMsge={
                quoteNumber.length <= 0
                  ? renderErrorMsge({
                      type: "input",
                      text: "quote / policy number",
                    })
                  : null
              }
            />
          </View>
          {preInspectionAlert()}
          {/* Button view */}
          <View style={styles.buttonView}>
            <PrimaryButton
              disabled={quoteNumber.length > 0 ? false : true}
              style={{ marginTop: 24 }}
              onPress={() => {
                checkPICondition();
              }}
            >
              {translate("Continue")}
            </PrimaryButton>
            <RoundButton
              style={{
                height: 50,
                borderColor: "#DDDDDD",
                borderWidth: 1,
                borderRadius: 16,
                marginTop: 18,
                width: SCREEN_WIDTH - 108,
                alignSelf: "center",
                justifyContent: "center",
                marginBottom: 20,
              }}
              Title={translate("Don’t have Quote/Policy No?")}
              onClicked={() => {
                navigation.navigate("WithOutQuote");
              }}
            ></RoundButton>
          </View>
        </View>
      </ScrollView>
    </View>
  );
};
export default WithQuote;

const styles = StyleSheet.create({
  main: {
    flex: 1,
    backgroundColor: "#FFFFFF",
  },
  imageView: {
    flex: 0.4,
    justifyContent: "center",
    alignItems: "center",
    marginTop: 50,
  },
  textView: {
    flex: 0.45,
  },
  buttonView: {
    flex: 0.15,
  },
  welcomeText: {
    fontSize: 18,
    fontFamily: "Muli-ExtraBold",
    marginBottom: 9,
    marginTop: 52,
  },
  subText: {
    fontFamily: "Muli-Regular",
    fontSize: 14,
    marginBottom: 23,
  },
  subView: {
    flex: 1,
    marginLeft: 24,
    marginRight: 24,
  },
});
