import { Alert, NativeModules, DeviceEventEmitter, View } from "react-native";
import React from "react";
import { useSelector } from "react-redux";
import reactotron from "reactotron-react-native";
import RNFetchBlob from "rn-fetch-blob";
import { SELFSURVEYSERVICE_DOCUMENT_URL } from "../Api/ApiUrls";
var mSensorManager = NativeModules.SensorManager;
var accelerometerData = [];
var gyroscopeData = [];
var magnetometerData = [];
var pedometerData = [];
var compassData = [];
var SensorDataInfo;

// capcture sensor data
export function startCapturingSensorData(int) {
  //Accelerometer
  mSensorManager.startAccelerometer(100); // To start the accelerometer with a minimum delay of 100ms between events.
  DeviceEventEmitter.addListener("Accelerometer", function (data) {
    (data.timestamp = new Date().getTime()), accelerometerData.push(data);
  });

  //Gyroscope
  mSensorManager.startGyroscope(100);
  DeviceEventEmitter.addListener("Gyroscope", function (data) {
    (data.timestamp = new Date().getTime()), gyroscopeData.push(data);
  });

  //Magnetometer
  mSensorManager.startMagnetometer(100);
  DeviceEventEmitter.addListener("Magnetometer", function (data) {
    (data.timestamp = new Date().getTime()), magnetometerData.push(data);
  });

  //Pedometer
  mSensorManager.startStepCounter(1000);
  DeviceEventEmitter.addListener("StepCounter", function (data) {
    (data.timestamp = new Date().getTime()), pedometerData.push(data);
  });
}
// genrate sensor data
export function genrateSensorFile(
  activityId,
  activityTypeId,
  licensePlateNumber,
  quoteNumber,
  sensorImageDetails
) {
  const date = new Date().getDate();
  const month = new Date().getMonth() + 1;
  const year = new Date().getFullYear();

  //Time calulation for the display on preciew Screen
  const hour = new Date().getHours();
  const minute = new Date().getMinutes();
  const seconds = new Date().getSeconds();

  SensorDataInfo = {
    activity_id: activityId,
    activity_type: activityTypeId,
    date_time:
      year +
      " " +
      month +
      " " +
      date +
      "  " +
      hour +
      ":" +
      minute +
      ":" +
      seconds,
    imageDetails: sensorImageDetails,
    policy_no: quoteNumber,
    reg_no: licensePlateNumber,
    sensor_data: {
      accelerometers: accelerometerData,
      compass: compassData,
      gyroscope: gyroscopeData,
      magnetometers: magnetometerData,
      millis: new Date().getTime(),
      pedometer: pedometerData,
    },
  };
  const filename = activityId + "_" + "Sensor.json";
  const destPath = RNFetchBlob.fs.dirs.CacheDir + "/" + filename;
  RNFetchBlob.fs
    .writeFile(destPath, JSON.stringify(SensorDataInfo, null, "  "), "utf8")
    .then((data) => {
      uploadSensorData("file://" + destPath, activityId, activityTypeId);
      RNFetchBlob.fs.exists(destPath).then((data) => {
        console.log("IS EXIST  >> ", data);
      });
    })
    .catch((e) => {
      console.log("ERROR    ", e);
    });

  // stop capture data once all photo completed
  mSensorManager.stopAccelerometer();
  mSensorManager.stopStepCounter();
  mSensorManager.stopMagnetometer();
  mSensorManager.stopGyroscope();
}

//upload sensor data file
const uploadSensorData = (uri, activityId, activityTypeId) => {
  try {
    const xhr = new XMLHttpRequest();
    const formData = new FormData();
    console.log("Sensor TO BE UPLOADED > > >   ", uri);
    const handleProgress = (event) => {
      reactotron.log(Math.round(event.loaded * 100) / event.total);
    };
    const documentUploadData = {
      activityId: activityId,
      geoLocation: {
        isBlocked: "",
        deviceName: "",
        latitude: "",
        longitude: "",
        operatingSystem: "",
        timezone: "",
        deviceTime: null,
        ipAddress: "",
        deviceIMEI: "",
        macAddress: "",
      },
      isLast: "false",
      isLastDocument: "false",
    };

    formData.append("file", {
      uri: uri,
      type: "image/jpeg",
      fileName: activityId + "_" + "Sensor",
      name: activityId + "_" + "Sensor.json",
    });
    formData.append("documentData", JSON.stringify(documentUploadData));

    xhr.upload.addEventListener("progress", handleProgress);
    xhr.addEventListener("load", () => {
      reactotron.log("Sensor file   >>>   100 ", xhr.response);
      console.log("Sensor Data Uploaded");
      console.log("Sensor Data STATUS  > > >", xhr.response);
    });
    xhr.open("POST", SELFSURVEYSERVICE_DOCUMENT_URL);
    xhr.setRequestHeader(
      "Accept",
      "*/*",
      "Content-Type",
      "multipart/form-data"
    );
    xhr.send(formData);
  } catch (error) {
    console.log("Error in Upload Sensor Data ", error);
  }
};
